@@ -829,9 +829,9 @@ def circleScar(mesh, path, list_face_of_vertice, limitY_min, limitY_max, index):
                 mesh_pre.vertices[idx_ver][2] =  mesh_pre.vertices[idx_ver][2] + _inc_Z*(sm - i)/sm
             else:
                 mesh_pre.vertices[idx_ver][2] =  mesh_pre.vertices[idx_ver][2] - _inc_Z*(sm - i)/sm
-    print(path + "_" + str(index) + ".obj")
-    mesh_pre.export(path + "_" + str(index) + ".obj")
-    return mesh_pre
+    newpath = path + "_" + str(index) + ".obj"
+    mesh_pre.export(newpath)
+    # return mesh_pre
 
 
 def scarCreatingV2(mesh, path, numGenCirScar=10):
